@@ -19,12 +19,12 @@ layout with a shader::
     from kivy.uix.boxlayout import BoxLayout
     from ae.kivy_glsl import ShadersMixin
 
-    class MyBoxLayoutWithShader(BoxLayout, ShadersMixin):
+    class MyBoxLayoutWithShader(ShadersMixin, BoxLayout):
 
 
 alternatively you can declare a your shader-widget as a new kv rule within a kv file::
 
-    <MyBoxLayoutWithShader@BoxLayout+ShadersMixin>
+    <MyBoxLayoutWithShader@ShadersMixin+BoxLayout>
 
 
 to register a shader, call the :meth:`ShadersMixin.add_shader` method::
@@ -78,21 +78,22 @@ is then set to False and an error message like the following gets printed on to
 
 some common failure reasons are:
 
-* missing declaration of used uniform input variables.
-* non-input/output variables declared on module level (they should be moved into main or any other function).
+    * missing declaration of used uniform input variables.
+    * non-input/output variables declared on module level (they should be moved into main or any other function).
+
+if a compile error occurred then the `run_state` value of the shader id dict will be set to `'error'` - check the value
+of the `error_message` key of the shader id dict for more details on the error.
 
 in other cases the shader code compiles fine but then the renderer is crashing in the vbo.so library and w/o
 printing any Python traceback to the console - see also `this Kivy issues <https://github.com/kivy/kivy/issues/6627>`_).
 
-sometimes this crashes can be prevented if the texture of the widget (or of the last shader) gets fetched
+if the crash only happens on some Adreno GPUs then see issues `https://github.com/kivy/python-for-android/issues/2723`_
+and `https://github.com/kivy/kivy/issues/8080`_ and a possible fix in `https://github.com/kivy/kivy/pull/8098`_.
+sometimes these type of crashes can be prevented if the texture of the widget (or of the last shader) gets fetched
 (w/ the function texture2D(texture0, tex_coord0)) - even if it is not used for the final gl_FragColor output variable.
-
 in some cases additional to fetch the texture, the return value of the `texture2D` call has to be accessed at least once
 at the first render cycle.
 
-if an error occurred then the `run_state` value of the shader id dict will be set to `'error'` - check the
-`error_message` value of the shader id dict for more details on the error.
-
 
 built-in shaders
 ----------------
@@ -127,7 +128,7 @@ from kivy.properties import ListProperty                        # type: ignore #
 from ae.base import UNSET                                       # type: ignore
 
 
-__version__ = '0.3.13'
+__version__ = '0.3.14'
 
 
 DEFAULT_FPS = 30.0                                              #: default frames-per-second
@@ -575,7 +576,7 @@ class ShadersMixin:
                                 `shader_code` key is a fragment shader (w/o a vertex shader), that will be automatically
                                 prefixed with the Kivy fragment shader header file template, if the $HEADER$ placeholder
                                 is not included in the shader code (even if it is commented out, like in the following
-                                glsl code line: `#ifdef GL_ES   //$HEADER$`.
+                                glsl code line: ``#ifdef GL_ES   //$HEADER$``).
         :return:                "" if shader is running/playing or error message string.
         """
         add_to = shader_id['add_to']
@@ -612,7 +613,7 @@ class ShadersMixin:
     def _pos_changed(self, *_args):
         """ pos changed event handler. """
         for shader_id in self.running_shaders:
-            shader_id['rectangle'].pos = self.to_window(*self.pos)
+            shader_id['rectangle'].pos = self.pos
 
     def _refresh_glsl(self, shader_id: ShaderIdType, _dt: float):
         """ timer/clock event handler to animate and sync one canvas shader. """
@@ -638,7 +639,7 @@ class ShadersMixin:
         glsl_kwargs = shader_id['glsl_dyn_args']
         ren_ctx['alpha'] = 0.693
         ren_ctx['contrast'] = 0.696
-        ren_ctx['win_pos'] = list(map(float, self.to_window(*self.pos)))
+        ren_ctx['win_pos'] = list(map(float, self.pos))
         ren_ctx['resolution'] = list(map(float, self.size))
         ren_ctx['tex_col_mix'] = 0.699
         if not callable(glsl_kwargs.get('time')):
